@@ -41,44 +41,34 @@ namespace aria2 {
 
 const std::string DHTResponseMessage::R("r");
 
-DHTResponseMessage::DHTResponseMessage(const SharedHandle<DHTNode>& localNode,
-                                       const SharedHandle<DHTNode>& remoteNode,
-                                       const std::string& transactionID):
-  DHTAbstractMessage(localNode, remoteNode, transactionID) {}
+DHTResponseMessage::DHTResponseMessage(
+    const std::shared_ptr<DHTNode>& localNode,
+    const std::shared_ptr<DHTNode>& remoteNode,
+    const std::string& transactionID)
+    : DHTAbstractMessage(localNode, remoteNode, transactionID)
+{
+}
 
 DHTResponseMessage::~DHTResponseMessage() {}
 
-const std::string& DHTResponseMessage::getType() const
-{
-  return R;
-}
+const std::string& DHTResponseMessage::getType() const { return R; }
 
 void DHTResponseMessage::fillMessage(Dict* msgDict)
 {
   msgDict->put(R, getResponse());
 }
 
-bool DHTResponseMessage::isReply() const
-{
-  return true;
-}
+bool DHTResponseMessage::isReply() const { return true; }
 
 std::string DHTResponseMessage::toString() const
 {
-  std::string s = strconcat
-    ("dht response ", getMessageType(),
-     " TransactionID=", util::toHex(getTransactionID()),
-     " Remote:", getRemoteNode()->getIPAddress(),
-     ":", util::uitos(getRemoteNode()->getPort()),
-     ", id=", util::toHex(getRemoteNode()->getID(), DHT_ID_LENGTH),
-     ", ");
-  if(!getVersion().empty()) {
-    s += "v=";
-    s += util::torrentPercentEncode(getVersion());
-    s += ", ";
-  }
-  s += toStringOptional();
-  return s;
+  return fmt("dht response %s TransactionID=%s Remote:%s(%u), id=%s, v=%s, %s",
+             getMessageType().c_str(), util::toHex(getTransactionID()).c_str(),
+             getRemoteNode()->getIPAddress().c_str(),
+             getRemoteNode()->getPort(),
+             util::toHex(getRemoteNode()->getID(), DHT_ID_LENGTH).c_str(),
+             util::torrentPercentEncode(getVersion()).c_str(),
+             toStringOptional().c_str());
 }
 
 } // namespace aria2
