@@ -161,25 +161,24 @@ std::string DefaultBtAnnounce::getAnnounceUrl()
   const size_t keyLen = 8;
   std::string uri = announceList_.getAnnounce();
   uri += uriHasQuery(uri) ? "&" : "?";
-  uri +=
-      fmt("info_hash=%s&"
-          "peer_id=%s&"
-          "uploaded=%" PRId64 "&"
-          "downloaded=%" PRId64 "&"
-          "left=%" PRId64 "&"
-          "compact=1&"
-          "key=%s&"
-          "numwant=%d&"
-          "no_peer_id=1",
-          util::torrentPercentEncode(bittorrent::getInfoHash(downloadContext_),
-                                     INFO_HASH_LENGTH).c_str(),
-          util::torrentPercentEncode(bittorrent::getStaticPeerId(),
-                                     PEER_ID_LENGTH).c_str(),
-          stat.getSessionUploadLength(), stat.getSessionDownloadLength(), left,
-          util::torrentPercentEncode(bittorrent::getStaticPeerId() +
-                                         PEER_ID_LENGTH - keyLen,
-                                     keyLen).c_str(),
-          numWant);
+  uri += fmt("info_hash=%s&"
+             "peer_id=%s&"
+             "uploaded=%" PRId64 "&"
+             "downloaded=%" PRId64 "&"
+             "left=%" PRId64 "&"
+             "compact=1&"
+             "key=%s&"
+             "numwant=%d&"
+             "no_peer_id=1",
+             util::percentEncode(bittorrent::getInfoHash(downloadContext_),
+                                 INFO_HASH_LENGTH).c_str(),
+             util::percentEncode(bittorrent::getStaticPeerId(), PEER_ID_LENGTH)
+                 .c_str(),
+             stat.getSessionUploadLength(), stat.getSessionDownloadLength(),
+             left, util::percentEncode(bittorrent::getStaticPeerId() +
+                                           PEER_ID_LENGTH - keyLen,
+                                       keyLen).c_str(),
+             numWant);
   if (tcpPort_) {
     uri += fmt("&port=%u", tcpPort_);
   }
@@ -190,7 +189,7 @@ std::string DefaultBtAnnounce::getAnnounceUrl()
   }
   if (!trackerId_.empty()) {
     uri += "&trackerid=";
-    uri += util::torrentPercentEncode(trackerId_);
+    uri += util::percentEncode(trackerId_);
   }
   if (option_->getAsBool(PREF_BT_FORCE_ENCRYPTION) ||
       option_->getAsBool(PREF_BT_REQUIRE_CRYPTO)) {
